@@ -207,7 +207,7 @@ class UserAuthenticator:
         """The port that will be used. |default| :code:`17653`"""
         self.host: str = '0.0.0.0'
         """the host the webserver will bind to. |default| :code:`0.0.0.0`"""
-        self.__state: str = str(get_uuid())
+        self.state: str = str(get_uuid())
         self.__callback_func = None
         self.__server_running: bool = False
         self.__loop: Union[asyncio.AbstractEventLoop, None] = None
@@ -215,6 +215,7 @@ class UserAuthenticator:
         self.__thread: Union[Thread, None] = None
         self.__user_token: Union[str, None] = None
         self.__can_close: bool = False
+        self.__is_closed = False
 
     def __build_auth_url(self):
         params = {
@@ -223,7 +224,7 @@ class UserAuthenticator:
             'response_type': 'code',
             'scope': build_scope(self.scopes),
             'force_verify': str(self.force_verify).lower(),
-            'state': self.__state
+            'state': self.state
         }
         return build_url(TWITCH_AUTH_BASE_URL + 'oauth2/authorize', params)
 
@@ -240,6 +241,8 @@ class UserAuthenticator:
                 pass
         for task in asyncio.all_tasks(self.__loop):
             task.cancel()
+        self.logger.info('shutting down oauth Webserver')
+        self.__is_closed = True
 
     def __run(self, runner: web.AppRunner):
         self.__runner = runner
@@ -270,7 +273,7 @@ class UserAuthenticator:
         val = request.rel_url.query.get('state')
         self.logger.debug(f'got callback with state {val}')
         # invalid state!
-        if val != self.__state:
+        if val != self.state:
             return web.Response(status=401)
         self.__user_token = request.rel_url.query.get('code')
         if self.__user_token is None:
@@ -307,6 +310,9 @@ class UserAuthenticator:
         :rtype: None or (str, str)
         """
         self.__callback_func = callback_func
+        self.__can_close = False
+        self.__user_token = None
+        self.__is_closed = False
 
         if user_token is None:
             self.__start()
@@ -335,6 +341,8 @@ class UserAuthenticator:
                 data: dict = await response.json()
         if callback_func is None:
             self.stop()
+            while not self.__is_closed:
+                await asyncio.sleep(0.1)
             if data.get('access_token') is None:
                 raise TwitchAPIException(f'Authentication failed:\n{str(data)}')
             return data['access_token'], data['refresh_token']
