@@ -18,6 +18,16 @@ T = TypeVar('T')
 
 
 class TwitchObject:
+    """
+    A lot of API calls return a child of this in some way (either directly or via generator).
+    You can always use the :const:`~twitchAPI.object.TwitchObject.to_dict()` method to turn that object to a dictionary.
+
+    Example:
+
+    .. code-block:: python
+
+        blocked_term = await twitch.add_blocked_term('broadcaster_id', 'moderator_id', 'bad_word')
+        print(blocked_term.id)"""
     @staticmethod
     def _val_by_instance(instance, val):
         if val is None:
@@ -45,6 +55,8 @@ class TwitchObject:
     def _dict_val_by_instance(instance, val, include_none_values):
         if val is None:
             return None
+        if instance is None:
+            return val
         origin = instance.__origin__ if hasattr(instance, '__origin__') else None
         if instance == datetime:
             return val.isoformat() if val is not None else None
@@ -77,7 +89,10 @@ class TwitchObject:
         return d
 
     def to_dict(self, include_none_values: bool = False) -> dict:
-        """build dict based on annotation types"""
+        """build dict based on annotation types
+
+        :param include_none_values: if fields that have None values should be included in the dictionary
+        """
         d = {}
         annotations = self._get_annotations()
         for name, val in self.__dict__.items():
@@ -89,6 +104,8 @@ class TwitchObject:
                 pass
             if val is None and not include_none_values:
                 continue
+            if name[0] == '_':
+                continue
             d[name] = TwitchObject._dict_val_by_instance(cls, val, include_none_values)
         return d
 
@@ -101,6 +118,18 @@ class TwitchObject:
 
 
 class IterTwitchObject(TwitchObject):
+    """Special type of :const:`~twitchAPI.object.TwitchObject`.
+       These usually have some list inside that you may want to dicrectly itterate over in your API usage but that also contain other usefull data
+       outside of that List.
+
+       Example:
+
+       .. code-block:: python
+
+          lb = await twitch.get_bits_leaderboard()
+          print(lb.total)
+          for e in lb:
+              print(f'#{e.rank:02d} - {e.user_name}: {e.score}')"""
 
     def __iter__(self):
         if not hasattr(self, 'data') or not isinstance(self.__getattribute__('data'), list):
@@ -110,6 +139,17 @@ class IterTwitchObject(TwitchObject):
 
 
 class AsyncIterTwitchObject(TwitchObject, Generic[T]):
+    """A few API calls will have usefull data outside of the list the pagination itterates over.
+       For those cases, this object exist.
+
+       Example:
+
+       .. code-block:: python
+
+           schedule = await twitch.get_channel_stream_schedule('user_id')
+           print(schedule.broadcaster_name)
+           async for segment in schedule:
+               print(segment.title)"""
 
     def __init__(self, _data, **kwargs):
         super(AsyncIterTwitchObject, self).__init__(**kwargs)
@@ -148,6 +188,8 @@ class AsyncIterTwitchObject(TwitchObject, Generic[T]):
             self.__setattr__(name, TwitchObject._val_by_instance(cls, _data.get(name)))
         data = self.__getattribute__(self._data['iter_field'])
         self.__idx = 0
+        if len(data) == 0:
+            raise StopAsyncIteration()
         return data[self.__idx]
 
 
@@ -401,7 +443,7 @@ class BroadcasterSubscription(TwitchObject):
     user_login: str
 
 
-class BroadcasterSubscriptions(IterTwitchObject):
+class BroadcasterSubscriptions(AsyncIterTwitchObject[BroadcasterSubscription]):
     total: int
     points: int
     data: List[BroadcasterSubscription]
